==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Виконуємо запис відео. Закрити вікно попри це?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>У вас немає прав доступу для роботи з цією текою</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Некоректна тека</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Основні</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Розташування файла</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Знімок</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Серійна знімання</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Затримка власного таймера</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Виведення</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Формат виведення</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 знімка</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 знімків</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>«Камера» — допоміжна програма для захоплення зображень та відео з відеокамери вашого персонального комп&apos;ютера або вебкамери.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Файл не збережено</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Зберегти до:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Фото:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Відео:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Параметри роздільності</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Роздільна здатність:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Створити знімок</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Записати відео</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Зупинити створення фотографій</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Вебкамери не знайдено</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Вебкамера використовується іншою програмою</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Зупинити записування</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Виконуємо запис відео. Закрити вікно попри це?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Надрукувати</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>У вас немає прав доступу для роботи з цією текою</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Некоректна тека</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Основні</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Розташування файла</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Знімок</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Серійна знімання</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Затримка власного таймера</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Виведення</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Формат виведення</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 знімка</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 знімків</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>«Камера» — допоміжна програма для захоплення зображень та відео з відеокамери вашого персонального комп&apos;ютера або вебкамери.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Файл не збережено</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Зберегти до:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Фото:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Відео:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Параметри роздільності</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Роздільна здатність:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Фотографії:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Відео:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Звукові ефекти</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Зупинити записування</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Надрукувати</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показати скорочення</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Зупинити створення фотографій</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Контекстне меню</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Створити знімок</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Записати відео</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Зупинити створення фотографій</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Вебкамери не знайдено</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Вебкамера використовується іншою програмою</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Зупинити записування</translation>
    </message>
</context>
</TS>
